#!/usr/bin/env python
# -- coding: utf-8 --

#Copyright (C) 2007   Authors: Jacobo Tarragón Cros, Víctor Muñoz Ferrara, William Viana Soares. 
#Email addresses: tarragon[AT]aditel[DOT]org, victorm[AT]aditel[DOT]org, wviana[AT]aditel[DOT]org
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.


import sys, os
from PyQt4 import QtCore, QtGui
from ui_configwindow import Ui_ConfigWindow
from musicquizz_core import Preferencias

class ConfigWindow(QtGui.QDialog, Ui_ConfigWindow):
	def __init__(self, prefs, parent=None):
		QtGui.QWidget.__init__(self, parent)
		
		self.setupUi(self)
		
		self.prefs_copy = prefs
		self.prefs = Preferencias(prefs.fichero)
		
		#Fine tunning
		self.txt_canciones.setText(self.prefs.ops.fichero)
		
		#como no puedo eliminar elementos de self.prefs.directorios tengo que trabajar con una copia
		self.directorios = [] 
		self.dir_original = []
		for dir in self.prefs.ops.directorios:
			self.lst_paths.addItem(dir)
			self.directorios.append(dir)
			self.dir_original.append(dir)
			
		self.opciones_mostrar = QtGui.QButtonGroup()
		self.opciones_mostrar.setExclusive(False)
		self.opciones_mostrar.addButton(self.chk_artista, 0)
		self.opciones_mostrar.addButton(self.chk_titulo, 1)
		
		self.chk_artista.setChecked(self.prefs.ops.autor)
		self.chk_titulo.setChecked(self.prefs.ops.titulo)
		
		if not self.prefs.ops.autor or not self.prefs.ops.titulo:
			if self.prefs.ops.titulo:
				self.chk_titulo.setEnabled(False)
			else:
				self.chk_artista.setEnabled(False)
		
		self.spn_rondas.setValue(self.prefs.ops.rondas)
		self.spn_opciones.setValue(self.prefs.ops.opciones)
		self.spn_tiempo.setValue(self.prefs.ops.tiempo)
		
		
		self.connect(self.btn_path, QtCore.SIGNAL("clicked()"), self.seleccionarDirectorio)
		self.connect(self.btn_addpath, QtCore.SIGNAL("clicked()"), self.anyadirDirectorio)
		self.connect(self.btn_rmpath, QtCore.SIGNAL("clicked()"), self.removerDirectorio)
		self.connect(self.btn_canciones, QtCore.SIGNAL("clicked()"), self.seleccionarFichero)
		self.connect(self.opciones_mostrar, QtCore.SIGNAL("buttonClicked(int)"), self.mostrarTituloAutor)
		self.connect(self.btn_aceptar, QtCore.SIGNAL("clicked()"), self.guardar)
		#self.connect(self.btn_cancelar, QtCore.SIGNAL("clicked()"), self.cancelar)
		self.connect(self.btn_cancelar, QtCore.SIGNAL("clicked()"), self.reject)
		self.connect(self.spn_tiempo, QtCore.SIGNAL("valueChanged(int)"), self.spn_tiempo.setValue)
		self.connect(self.spn_rondas, QtCore.SIGNAL("valueChanged(int)"), self.spn_rondas.setValue)
		self.connect(self.spn_opciones, QtCore.SIGNAL("valueChanged(int)"), self.spn_opciones.setValue)
	
	def seleccionarDirectorio(self):    
		dir = QtGui.QFileDialog.getExistingDirectory(self, self.tr("Directorio de canciones - MusicQuizz"))
		if dir:
			self.txt_path.setText(dir)
	
	def seleccionarFichero(self):
		fich = QtGui.QFileDialog.getOpenFileName(self, self.tr("Fichero de canciones - MusicQuizz"),
							 self.tr(""),
							 self.tr("Ficheros de canciones (*.dat);; Todos los ficheros (*)" ))
		if fich and os.path.isfile(fich):
			self.txt_canciones.setText(fich)
			
		
	def anyadirDirectorio(self):
	
		if self.txt_path.text() != "" and  self.txt_path.text() not in self.directorios:
			if os.path.exists(self.txt_path.text()) and os.path.isdir(self.txt_path.text()):
				self.lst_paths.addItem(self.txt_path.text())
				self.directorios.append(str(self.txt_path.text()))
				self.prefs.ops.directorios.append(str(self.txt_path.text()),None)
			else:
				QtGui.QMessageBox.information(self, self.tr("Directorio no válido - MusicQuizz"), 
							      self.tr("Debes introducir un directorio válido"))
	
	def removerDirectorio(self):
		self.prefs.ops.directorios.__init__() #reiniciarlo ya que no puedo eliminar elementos
		del self.directorios[self.lst_paths.currentRow()]
		for dir in self.directorios:
			self.prefs.ops.directorios.append(dir,None)
		self.lst_paths.takeItem(self.lst_paths.currentRow())
		
	
	def mostrarTituloAutor(self, i):
		"""Este método sirve para asegurarse de que siempre hay alguna de las dos opciones seleccionadas"""
		self.prefs.ops.titulo = self.chk_titulo.isChecked()
		self.prefs.ops.autor = self.chk_artista.isChecked()
		if self.opciones_mostrar.button(i).isChecked():
			self.opciones_mostrar.button((i+1)%2).setEnabled(True)
			self.opciones_mostrar.button(i).setChecked(True)
		else:
			self.opciones_mostrar.button((i+1)%2).setEnabled(False)
			self.opciones_mostrar.button(i).setChecked(False)
		#if not self.opciones_mostrar.button(0).isChecked() and not self.opciones_mostrar.button(1).isChecked():
			#self.opciones_mostrar.button(i).setChecked(True)
		#self.prefs.ops.titulo = self.chk_titulo.isChecked()
		#self.prefs.ops.autor = self.chk_artista.isChecked()
	
			
	def guardar(self):
		self.prefs_copy = self.prefs
		self.prefs_copy.ops.rondas = self.spn_rondas.value()
		self.prefs_copy.ops.tiempo = self.spn_tiempo.value()
		self.prefs_copy.ops.opciones = self.spn_opciones.value()
		
		self.prefs_copy.guardar()
		self.accept() #devuelve el control a la aplicación principal y devuelve un 1
	
	#def cancelar(self):
		#self.prefs.ops.directorios.__init__()
		#for dir in self.dir_original:
			#self.prefs.ops.directorios.append(dir, None)
		#self.reject()


if __name__ == '__main__':
	app = QtGui.QApplication(sys.argv)
	config_dialog = ConfigWindow()
	sys.exit(config_dialog.exec_())